"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Popover = void 0;

var _react = _interopRequireDefault(require("react"));

var _Overlay = require("../Overlay/Overlay");

var _hooks = require("../hooks");

var _Popper = require("../Popper/Popper");

var _OverlayBackdrop = require("../Overlay/OverlayBackdrop");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Popover = props => {
  var _props$focusable;

  let triggerRef = _react.default.useRef(null);

  let [overlayRef, setOverlayRef] = _react.default.useState({
    current: null
  });

  const [isOpen, setIsOpen] = (0, _hooks.useControllableState)({
    defaultValue: props.defaultIsOpen,
    value: props.isOpen,
    onChange: props.onOpenChange
  });

  const handleOpen = () => {
    setIsOpen(true);
  };

  const handleClose = () => {
    setIsOpen(false);
  };

  const isTriggerElement = /*#__PURE__*/_react.default.isValidElement(props.trigger);

  const isTriggerRef = props.trigger.hasOwnProperty('current');

  if (!isTriggerElement && !isTriggerRef) {
    console.warn(`Popover: Invalid 'trigger' prop received, please pass a valid ReactElement or a Ref`);
  } // @ts-ignore - We already checked isValidElement above.


  const triggerExistingProps = isTriggerElement ? props.trigger.props : {};
  const handlers = (0, _hooks.useOn)({
    on: props.on,
    onClose: handleClose,
    onOpen: handleOpen,
    overlayRef,
    ...triggerExistingProps
  });
  let triggerElem = null;

  if (isTriggerRef) {
    // @ts-ignore
    triggerRef = props.trigger;
  } else if (isTriggerElement) {
    // @ts-ignore - We already checked isValidElement above.
    triggerElem = /*#__PURE__*/_react.default.cloneElement(props.trigger, {
      ref: triggerRef,
      ...handlers
    });
  } // ARIA props


  const {
    triggerProps,
    contentProps
  } = (0, _hooks.usePopover)({
    isOpen,
    disableAriaAttributes: props.disableAriaAttributes
  });

  if (triggerElem) {
    triggerElem = /*#__PURE__*/_react.default.cloneElement(triggerElem, { ...triggerProps
    });
  } // If trigger is hover, we shouldn't shift user's focus


  const isFocusabe = props.on !== 'hover';
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, triggerElem, /*#__PURE__*/_react.default.createElement(_Overlay.Overlay, {
    isOpen: isOpen,
    onClose: handleClose,
    isKeyboardDismissable: props.isKeyboardDismissable,
    focusable: (_props$focusable = props.focusable) !== null && _props$focusable !== void 0 ? _props$focusable : isFocusabe,
    animated: props.animated,
    mode: props.mode,
    animationEntryDuration: props.animationEntryDuration,
    animationExitDuration: props.animationExitDuration,
    overlayRef: overlayRef,
    triggerRef: triggerRef,
    shouldCloseOnOutsideClick: props.shouldCloseOnOutsideClick
  }, /*#__PURE__*/_react.default.createElement(_Popper.Popper, _extends({}, props, {
    onClose: handleClose,
    triggerRef: triggerRef,
    contentProps: contentProps,
    setOverlayRef: setOverlayRef
  }))));
};

exports.Popover = Popover;
Popover.Content = _Popper.Popper.Content;
Popover.Arrow = _Popper.Popper.Arrow;
Popover.Backdrop = _OverlayBackdrop.OverlayBackdrop;
//# sourceMappingURL=Popover.js.map