"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Tooltip = void 0;

var _react = _interopRequireDefault(require("react"));

var _Overlay = require("../Overlay/Overlay");

var _hooks = require("../hooks");

var _Popper = require("../Popper/Popper");

var _OverlayBackdrop = require("../Overlay/OverlayBackdrop");

var _reactNative = require("react-native");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

// Tooltip's code is almost same as Popover with some exceptions. Defaults to on="hover"
// and focusable=false and also has different ARIA attributes via useTooltip hook.
const Tooltip = props => {
  var _props$on;

  let triggerRef = _react.default.useRef(null);

  const [isOpen, setIsOpen] = (0, _hooks.useControllableState)({
    defaultValue: props.defaultIsOpen,
    value: props.isOpen,
    onChange: props.onOpenChange
  });

  const handleOpen = () => {
    setIsOpen(true);
  };

  const handleClose = () => {
    setIsOpen(false);
  };

  let triggerElem = null;

  const isTriggerElement = /*#__PURE__*/_react.default.isValidElement(props.trigger);

  const isTriggerRef = props.trigger.hasOwnProperty('current');

  if (!isTriggerElement && !isTriggerRef) {
    console.warn(`Tooltip: Invalid 'trigger' prop received, please pass a valid ReactElement or a Ref`);
  } // @ts-ignore - We already checked isValidElement above.


  const triggerExistingProps = isTriggerElement ? props.trigger.props : {};
  const handlers = (0, _hooks.useOn)({
    on: ((_props$on = props.on) !== null && _props$on !== void 0 ? _props$on : _reactNative.Platform.OS === 'web') ? 'hover' : 'press',
    onClose: handleClose,
    onOpen: handleOpen,
    ...triggerExistingProps
  }); // Received a trigger ref

  if (isTriggerRef) {
    // @ts-ignore
    triggerRef = props.trigger;
  } // Received a trigger element
  else if (isTriggerElement) {
      // @ts-ignore - We already checked isValidElement above.
      triggerElem = /*#__PURE__*/_react.default.cloneElement(props.trigger, {
        ref: triggerRef,
        ...handlers
      });
    } // ARIA props


  const {
    triggerProps,
    contentProps
  } = (0, _hooks.useTooltip)({
    isOpen,
    disableAriaAttributes: props.disableAriaAttributes
  });

  if (triggerElem) {
    triggerElem = /*#__PURE__*/_react.default.cloneElement(triggerElem, { ...triggerProps
    });
  }

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, triggerElem, /*#__PURE__*/_react.default.createElement(_Overlay.Overlay, {
    isOpen: isOpen,
    onClose: handleClose,
    isKeyboardDismissable: props.isKeyboardDismissable,
    focusable: false,
    mode: props.mode,
    animated: props.animated,
    animationEntryDuration: props.animationEntryDuration,
    animationExitDuration: props.animationExitDuration
  }, /*#__PURE__*/_react.default.createElement(_Popper.Popper, _extends({}, props, {
    onClose: handleClose,
    triggerRef: triggerRef,
    contentProps: contentProps
  }))));
};

exports.Tooltip = Tooltip;
Tooltip.Content = _Popper.Popper.Content;
Tooltip.Arrow = _Popper.Popper.Arrow;
Tooltip.Backdrop = _OverlayBackdrop.OverlayBackdrop;
//# sourceMappingURL=index.js.map