import React from 'react';
import { Animated, Modal, StatusBar, StyleSheet } from 'react-native';
import { OverlayContainer } from './index';
import { OverlayContext } from './context';
import { useAnimatedStyles } from '../hooks'; // This is iOS/Android only implementation. Refer Overlay.web.tsx for Web implementation

export function Overlay(props) {
  const {
    isOpen,
    children,
    onClose,
    focusable = true,
    animated = true,
    mode = 'single',
    animationEntryDuration,
    animationExitDuration
  } = props;
  const {
    styles,
    isExited
  } = useAnimatedStyles({
    animated,
    animationEntryDuration,
    animationExitDuration,
    isOpen
  });

  if (!isOpen && isExited) {
    return null;
  } // If focusable we render it in RN modal so it shifts accessibility focus


  const content = focusable && mode === 'single' ? /*#__PURE__*/React.createElement(Modal, {
    visible: true,
    transparent: true
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [StyleSheet.absoluteFill, styles],
    pointerEvents: "box-none"
  }, /*#__PURE__*/React.createElement(OverlayContext.Provider, {
    value: {
      onClose
    }
  }, children))) : /*#__PURE__*/React.createElement(OverlayContainer, null, /*#__PURE__*/React.createElement(Animated.View, {
    style: [StyleSheet.absoluteFill, styles, {
      marginTop: StatusBar.currentHeight
    }],
    pointerEvents: "box-none"
  }, /*#__PURE__*/React.createElement(OverlayContext.Provider, {
    value: {
      onClose
    }
  }, children)));
  return content;
}
//# sourceMappingURL=Overlay.js.map