import React, { RefObject } from 'react';
import { Animated } from 'react-native';
declare type IParams = {
    enabled?: boolean;
    onClose: () => void;
};
export declare const useKeyboardDismissable: ({ enabled, onClose }: IParams) => void;
export declare const useElementByType: (children: React.ReactNode, name: string) => undefined;
interface UseControllableStateProps<T> {
    /**
     * The value to used in controlled mode
     */
    value?: T;
    /**
     * The initial value to be used, in uncontrolled mode
     */
    defaultValue?: T | (() => T);
    /**
     * The callback fired when the value changes
     */
    onChange?: (value: T) => void;
    /**
     * The component name (for warnings)
     */
    name?: string;
}
/**
 * React hook for using controlling component state.
 * @param props
 */
export declare function useControllableState<T>(props: UseControllableStateProps<T>): [T, React.Dispatch<React.SetStateAction<T>>];
export declare const usePopover: (props: {
    isOpen: boolean;
    disableAriaAttributes?: boolean;
}) => {
    triggerProps: any;
    contentProps: any;
};
export declare const useTooltip: (props: {
    isOpen: boolean;
    disableAriaAttributes?: boolean;
}) => {
    triggerProps: any;
    contentProps: any;
};
declare type IOnProps = {
    on?: 'press' | 'longPress' | 'hover';
    onHoverIn?: () => void;
    onHoverOut?: () => void;
    onFocus?: () => void;
    onBlur?: () => void;
    onPress?: () => void;
    onLongPress?: () => void;
    onOpen: () => void;
    onClose: () => void;
    overlayRef?: any;
};
export declare const useOn: (props: IOnProps) => {
    onHoverIn: (event: unknown) => void;
    onHoverOut: (event: unknown) => void;
    onFocus: (event: unknown) => void;
    onBlur: (event: unknown) => void;
} | {
    onPress: (event: unknown) => void;
    onLongPress?: undefined;
} | {
    onLongPress: (event: unknown) => void;
    onPress?: undefined;
} | {
    onPress?: undefined;
    onLongPress?: undefined;
};
declare type IProps = {
    animated: boolean;
    animationEntryDuration?: number;
    animationExitDuration?: number;
    isOpen?: boolean;
};
export declare const useAnimatedStyles: ({ animated, animationEntryDuration, animationExitDuration, isOpen, }: IProps) => {
    styles: {
        opacity?: undefined;
    };
    isExited: boolean;
} | {
    styles: {
        opacity: Animated.Value;
    };
    isExited: boolean;
};
declare type IOutsideClickListener = {
    refs?: Array<RefObject<any> | undefined>;
    onClose: any;
    enabled?: boolean;
};
export declare const useCloseOnOutsideClick: ({ refs, onClose, enabled, }: IOutsideClickListener) => void;
export {};
